/*********************************************************************************
**
**   $Id: PartsForm.cpp,v 1.2 2004/04/03 14:04:53 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qlistbox.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qsettings.h>
#include <qsqlquery.h>

#include "PartsForm.h"
#include "confdefs.h"

extern QSettings Config;

extern QSqlDatabase *autohouse;

PartsForm::PartsForm(QWidget *pParent, const char *pName, WFlags f) :
           DataForm(autohouse, "parts", 7, 6, pParent, pName, f)
{
   printf("PartsForm::PartsForm(): Enter()\n");
   fflush(stdout);

   inTransaction = false;

   pnEdit =     new QLineEdit(this);
   supplySelect = new YesNoSelect(this);
   QString s1 = Config.readEntry(CONFIG_ENTRY_MAKES);
   printf("PartsForm::PartsForm(): Config.readEntry(%s) = |%s|\n", CONFIG_ENTRY_MAKES, (const char *)s1);
   makeSelect = new StringSelect(s1, this, 0);
   QString s2 = Config.readEntry(CONFIG_ENTRY_UNITS);
   printf("PartsForm::PartsForm(): Config.readEntry(%s) = |%s|\n", CONFIG_ENTRY_UNITS, (const char *)s2);
   unitSelect = new StringSelect(s2, this, 0);
   QString s3 = Config.readEntry(CONFIG_ENTRY_PARTS_CATEGORIES);
   printf("PartsForm::PartsForm(): Config.readEntry(%s) = |%s|\n", CONFIG_ENTRY_PARTS_CATEGORIES, (const char *)s2);
   categorySelect = new StringSelect(s3, this, 0);
   
   DataFields fields[] =
   {
      { "pn",        "Part #",         0,  0,  0,  0,  0,    0,   0, "",   pnEdit, NULL },
      { "make",      "Make",           0,  1,  0,  0,  0,    0,   0, "",   makeSelect, "strsel" },
      { "category",  "Category",       0,  2,  0,  0,  0,    0,   0, "",   categorySelect, "strsel" },
      { "descr",     "Descr.",         1,  0,  3,  0,  0,    0,   0, "",   NULL, NULL },
      { "measure",   "Unit of Meas.",  2,  0,  0,  0,  0,    0,   0, "",   unitSelect, "strsel" },
      { "lowmark",   "Low Threshhold", 3,  0,  0,  0,  0,    0,   0, "",   NULL, NULL },
      { "buylevel",  "Buy to level",   3,  1,  0,  0,  0,    0,   0, "",   NULL, NULL },
      { "onhand",    "Qty In stock",   3,  2,  0,  0,  0,    0,   0, "",   NULL, NULL },
      { "cost",      "Cost",           4,  0,  0,  0,  0,    0,   0, "",   NULL, NULL },
      { "retail",    "Retail",         4,  1,  0,  0,  0,    0,   0, "",   NULL, NULL },
      { "supply",    "Supply",         4,  2,  3,  0,  0,    0,   0, "",   supplySelect, "yesno" },
      {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL }
   };
   printf("PartsForm::PartsForm(): Setting Fields()\n");
   fflush(stdout);
   setFields(fields);
   printf("PartsForm::PartsForm(): Exit()\n");
   fflush(stdout);
}

void PartsForm::deleteRecord() 
{
   QString s;
   printf("PartsForm::deleteRecord(): Enter()\n");
   fflush(stdout);
   s = "Deletng Part '" +
        pnEdit->text() +
        "'. This operation cannot be undone, Are you sure?"; 
   printf("PartsForm::deleteRecord(): Opening Message Box\n");
   fflush(stdout);
   if (QMessageBox::warning(NULL, "Delete Transaction", s, QMessageBox::Yes | QMessageBox::Default, 
                           QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes) 
   {
      printf("PartsForm::deleteRecord(): deleting record()\n");
      fflush(stdout);
      DataForm::deleteRecord();
   }
   printf("PartsForm::deleteRecord(): Exit()\n");
   fflush(stdout);
}

void PartsForm::insertRecord()
{
   beginTransaction();
   DataForm::insertRecord();  
}

void PartsForm::updateRecord()
{
   beginTransaction();
   DataForm::updateRecord();  
}

void PartsForm::beginTransaction()
{
   if ( ! inTransaction ) 
   {
      DataForm::beginTransaction();
      inTransaction = true;
   }
}

void PartsForm::commitTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::commitTransaction();
      inTransaction = false;
   }
}

void PartsForm::rollbackTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::rollbackTransaction();
      inTransaction = false;
   }
}

bool PartsForm::isInTransaction()
{
   printf("PartsForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   return(inTransaction);
}

