/*********************************************************************************
**
**   $Id: VehcForm.cpp,v 1.8 2004/06/28 11:58:28 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qlistbox.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qsettings.h>
#include <qsqlquery.h>
#include "confdefs.h"
#include "VehcForm.h"

extern QSettings Config;

extern QSqlDatabase *autohouse;

VehcForm::VehcForm(QWidget *pParent, const char *pName, WFlags f) :
           DataForm(autohouse, "vehicles", 4, 3, pParent, pName, f)
{
   printf("VehcForm::VehcForm(): Enter()\n");
   fflush(stdout);
   inTransaction = false;

   QString s1 = Config.readEntry(CONFIG_ENTRY_MAKES);
   printf("PartsForm::PartsForm(): Config.readEntry(%s) = |%s|\n", CONFIG_ENTRY_MAKES, (const char *)s1);
   makeSelect = new StringSelect(s1, this, 0);

   ownerEdit =    new QLineEdit(this);
   modelEdit =    new QLineEdit(this);
   yearEdit =     new QLineEdit(this);
   tagEdit =      new QLineEdit(this);
   vinEdit =      new QLineEdit(this);

   ownerEdit->setEnabled(false);

   DataFields fields[] =
   {
      { "owner",     "Cust #",         0,  0,  0,  0,  5,  0,  1, "",   ownerEdit, NULL },
      { "make",      "Make",           1,  0,  0,  0,  4,  0,  0, "",   makeSelect, "strsel" },
      { "model",     "Model",          1,  1,  0,  0,  4,  0,  0, "",   modelEdit, NULL },
      { "model_yr",  "Year",           1,  2,  0,  0,  4,  0,  0, "",   yearEdit, NULL },
      { "odom",      "Odometer",       2,  0,  0,  0,  4,  0,  0, "",   NULL, NULL },
      { "tag",       "Tags",           2,  1,  0,  0,  4,  0,  0, "",   tagEdit, NULL },
      { "color",     "Color",          2,  2,  0,  0,  4,  0,  0, "",   NULL, NULL },
      { "engine",    "Engine",         3,  0,  2,  0,  4,  0,  0, "",   NULL, NULL },
      { "trans",     "Trans",          3,  2,  0,  0,  4,  0,  0, "",   NULL, NULL },
      { "vin",       "VIN",            4,  0,  3,  0,  4,  0,  0, "",   vinEdit, NULL },
      {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL }
   };
   printf("VehcForm::VehcForm(): Setting Fields()\n");
   fflush(stdout);
   setFields(fields);
   setEnabled(false);
   printf("VehcForm::VehcForm(): Exit()\n");
   fflush(stdout);
}

void VehcForm::setEnabled(bool b) 
{
   modelEdit->setEnabled(b);
   makeSelect->setEnabled(b);
   yearEdit->setEnabled(b);
   tagEdit->setEnabled(b);
   vinEdit->setEnabled(b);
}

void VehcForm::setReadOnly(bool b) 
{
   modelEdit->setReadOnly(b);
   makeSelect->setEnabled(b);
   yearEdit->setReadOnly(b);
   tagEdit->setReadOnly(b);
   vinEdit->setReadOnly(b);
   vinEdit->setReadOnly(b);
}

void VehcForm::deleteRecord() 
{
   QString s, vehicle, owner;
   printf("VehcForm::deleteRecord(): Enter()\n");
   fflush(stdout);
   vehicle = getLastIdent();
//   QString sql = "select owner, workorders from vehicles_v where ident = '" + vehicle + "'";
   QString sql = "select count(*) from workorders where vehicle = '" + vehicle + "'";
   printf("VehcForm::deleteRecord(): sql = |%s|\n", (const char*)sql);
   fflush(stdout);
   QSqlQuery *query = new QSqlQuery(sql);
   if ( query->next() ) 
   {
      int workorders = query->value(0).toInt();
      if ( workorders > 0 ) 
      {
         QString s = "Vehicles referenced in existing work orders cannot be deleted";
         QMessageBox::warning(NULL, "Delete Transaction", s, QMessageBox::Ok, QMessageBox::NoButton);
      }
      else 
      {
         sql = "select name from customers where ident = (select owner from vehicles where ident = '" + vehicle + "')";
         printf("VehcForm::deleteRecord(): sql = |%s|\n", (const char*)sql);
         fflush(stdout);
         QSqlQuery *q1 = new QSqlQuery(sql);
         if ( q1->next() ) 
         {
            owner = q1->value(0).toString();
            s = "Deletng Vehicle of Make '" +
                 makeSelect->text() +
                 "', Model '" +
                 modelEdit->text() +
                 "', Tag '" +
                 tagEdit->text() +
                 "', and VIN '" +
                 vinEdit->text() +
                 "' owned by '" + owner + "'. Are you sure?"; 
            printf("VehcForm::deleteRecord(): Opening Message Box\n");
            fflush(stdout);
            if (QMessageBox::warning(NULL, "Delete Transaction", s, QMessageBox::Yes | QMessageBox::Default, 
                                    QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes) 
            {
               printf("VehcForm::deleteRecord(): deleting record()\n");
               fflush(stdout);
               DataForm::deleteRecord();
            }
         }
      }
   }
   printf("VehcForm::deleteRecord(): Exit()\n");
   fflush(stdout);
}

void VehcForm::insertRecord()
{
   beginTransaction();
   DataForm::insertRecord();  
   printf("VehcEdit::insertRecord(): owner = |%s|\n", (const char *)owner);
   if ( owner != "" ) 
   {
      printf("VehcEdit::insertRecord(): Setting owner field = |%s|\n", (const char *)owner);
      ownerEdit->setText(owner);
   }
   setEnabled(true);
}

void VehcForm::updateRecord()
{
   beginTransaction();
   if ( owner != "" ) 
   {
      ownerEdit->setText(owner);
   }
   DataForm::updateRecord();  
   setEnabled(true);
}

void VehcForm::beginTransaction()
{
   if ( ! inTransaction ) 
   {
      DataForm::beginTransaction();
      inTransaction = true;
   }
}

void VehcForm::commitTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::commitTransaction();
      inTransaction = false;
   }
}

void VehcForm::rollbackTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::rollbackTransaction();
      inTransaction = false;
   }
}

void VehcForm::setOwner(QString _owner)
{
   printf("VehcForm::setOwner(): Setting owner |%s|\n", (const char *)_owner);
   owner = _owner;
}

bool VehcForm::isInTransaction()
{
   printf("VehcForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   return(inTransaction);
}


void VehcForm::refresh(QSqlRecord *r)
{
   printf("VehcForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   if ( r != NULL ) 
   {
      DataForm::refresh(r);
      setEnabled(true);
   }
}

void VehcForm::refresh(QString s)
{
   printf("CustForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   DataForm::refresh(s);
   setEnabled(true);
}

